@@ -20,6 +20,8 @@ base_validators = [
     # url of the main Mobilizon instance to download events from
     Validator("source.mobilizon.url", must_exist=True, is_type_of=str),
     Validator("source.mobilizon.group", must_exist=True, is_type_of=str),
+    Validator("db_path", must_exist=True, is_type_of=str),
+    Validator("locale", must_exist=True, is_type_of=str, default="en-us"),
 ]
 
 activeness_validators = [
